@@ -22,20 +22,20 @@ RED_COLOR = "\u001b[31m"  # Makes the text red
 @click.option("--caption", "-ca",
               is_flag=True,
               help="Download subtitles")
-@click.option("--course", "-c", help="Example: 'Java 8 Essential'")
+@click.option("--course", "-c", help="Example: 'java-8-essential'")
 def main(cookies, course, resolution, caption):
     """
     Linkedin learning video downloader cli tool
 
-    example: llvd --course "Java 8 Essential"
+    example: llvd --course "java-8-essential"
     """
     if len(sys.argv) == 1:
         click.echo(f"{RED_COLOR}{BOLD}Missing required arguments: llvd --help")
         sys.exit(0)
 
-    course = course.lower().replace("c#", "c-sharp").replace(".net", "dot-net")
+    course = course.lower().replace("c#", "c-sharp").replace(".net", "-dot-net")
     without_chars = re.sub(r'[\':)(,>.’/]', " ", course.strip()).replace("«", " ").replace("-»", " ").replace("»", " ").strip()
-    course_slug= re.sub(r'(\s+)', "-", without_chars.lower())
+    course_slug= re.sub(r'(\s+)', "-", without_chars.lower()).replace("--", "-")
     email = ""
     password = ""
     if cookies:
